@@ -1,9 +1,11 @@
-//! #alpm-utils
+//! # alpm-utils
 //!
 //! A utility libary that provides some common functionality an alpm user may requre.
 
 #![warn(missing_docs)]
 
+#[cfg(feature = "conf")]
+mod conf;
 #[cfg(feature = "alpm")]
 mod db;
 /// Utils for dependency checking.
@@ -11,6 +13,8 @@ mod db;
 pub mod depends;
 mod target;
 
+#[cfg(feature = "conf")]
+pub use crate::conf::*;
 #[cfg(feature = "alpm")]
 pub use crate::db::*;
 pub use crate::target::*;
